This is a historic tribunal. The functions of this tribunal have been transferred to the General Regulatory Chamber of the First-tier Tribunal in 2009. The GRC began transferring records to Find Case Law in 2022. To view an archived version of the decisions of this tribunal from 2000-2024 visit the [UK Government Web Archive](https://webarchive.nationalarchives.gov.uk/ukgwa/20241206055345/https://transportappeals.decisions.tribunals.gov.uk/Aspx/Default.aspx).
